# Specio

Specio is a python library for interacting with spectrometers. Currently only
the Colorimetry Research family is supported, and particularly this library is
tested and maintained with a CR300.

This library also provides a virtual spectrometer which provides semi-random
SPDs as measurements.

## Usage

See Examples Folder
